==> moonlight-1.20-2.16.15-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/entity/ImprovedFallingBlockEntity.java <==
package net.mehvahdjukaar.moonlight.api.entity;

import net.minecraft.class_1282;
import net.minecraft.class_1299;
import net.minecraft.class_1540;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_1935;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2512;
import net.minecraft.class_2680;
import net.minecraft.class_2741;

public class ImprovedFallingBlockEntity extends class_1540 {

    protected boolean saveTileDataToItem;

    public ImprovedFallingBlockEntity(class_1299<? extends class_1540> type, class_1937 level) {
        super(type, level);
        saveTileDataToItem = false;
    }

    public ImprovedFallingBlockEntity(class_1299<? extends class_1540> type, class_1937 level, class_2338 pos,
                                      class_2680 blockState, boolean saveDataToItem) {
        super(type, level);
        this.field_23807 = true;
        this.field_6014 = pos.method_10263() + 0.5D;
        this.field_6036 = pos.method_10264();
        this.field_5969 = pos.method_10260() + 0.5D;
        this.method_5814(field_6014, field_6036 + ((1.0F - this.method_17682()) / 2.0F), field_5969);
        this.method_18799(class_243.field_1353);
        this.method_6963(this.method_24515());
        this.setBlockState(blockState);
        this.saveTileDataToItem = saveDataToItem;
    }

    public static ImprovedFallingBlockEntity fall(class_1299<? extends class_1540> type, class_1937 level,
                                                  class_2338 pos, class_2680 state, boolean saveDataToItem) {
        ImprovedFallingBlockEntity entity = new ImprovedFallingBlockEntity(type, level, pos, state,
                saveDataToItem);
        level.method_8652(pos, state.method_26227().method_15759(), 3);
        level.method_8649(entity);
        return entity;
    }

    public void setSaveTileDataToItem(boolean b) {
        this.saveTileDataToItem = b;
    }

    @Override
    public void method_5652(class_2487 tag) {
        super.method_5652(tag);
        tag.method_10556("saveToItem", this.saveTileDataToItem);
    }

    @Override
    public void method_5749(class_2487 tag) {
        super.method_5749(tag);
        this.saveTileDataToItem = tag.method_10577("saveToItem");
    }

    //workaround
    public void setBlockState(class_2680 state) {
        if (state.method_28498(class_2741.field_12508)) {
            state = state.method_11657(class_2741.field_12508, false);
        }
        class_2487 tag = new class_2487();
        tag.method_10566("BlockState", class_2512.method_10686(state));
        tag.method_10569("Time", this.field_7192);
        this.method_5749(tag);
    }

    @Override
    public class_1542 method_5870(class_1935 itemIn, int offset) {
        class_1799 stack = new class_1799(itemIn);
        if (itemIn instanceof class_2248 && this.saveTileDataToItem && this.field_7194 != null) {
            stack.method_7959("BlockEntityTag", this.field_7194);
        }
        return this.method_5699(stack, offset);
    }

    @Override
    public boolean method_5747(float pFallDistance, float pMultiplier, class_1282 pSource) {
        return super.method_5747(pFallDistance, pMultiplier, pSource);
    }

    public void setCancelDrop(boolean cancelDrop) {
        this.field_7189 = cancelDrop;
    }
}

==> moonlight-1.21-2.24.1-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/entity/ImprovedFallingBlockEntity.java <==
package net.mehvahdjukaar.moonlight.api.entity;

import net.mehvahdjukaar.moonlight.core.Moonlight;
import net.minecraft.class_1282;
import net.minecraft.class_1299;
import net.minecraft.class_1540;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_1935;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2512;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_2741;

public class ImprovedFallingBlockEntity extends class_1540 {

    protected boolean saveTileDataToItem;

    public ImprovedFallingBlockEntity(class_1299<? extends class_1540> type, class_1937 level) {
        super(type, level);
        saveTileDataToItem = false;
    }

    public ImprovedFallingBlockEntity(class_1299<? extends class_1540> type, class_1937 level, class_2338 pos,
                                      class_2680 blockState, boolean saveDataToItem) {
        super(type, level);
        this.field_23807 = true;
        this.field_6014 = pos.method_10263() + 0.5D;
        this.field_6036 = pos.method_10264();
        this.field_5969 = pos.method_10260() + 0.5D;
        this.method_5814(field_6014, field_6036 + ((1.0F - this.method_17682()) / 2.0F), field_5969);
        this.method_18799(class_243.field_1353);
        this.method_6963(this.method_24515());
        this.setBlockState(blockState);
        this.saveTileDataToItem = saveDataToItem;
    }

    public static ImprovedFallingBlockEntity fall(class_1299<? extends class_1540> type, class_1937 level,
                                                  class_2338 pos, class_2680 state, boolean saveDataToItem) {
        ImprovedFallingBlockEntity entity = new ImprovedFallingBlockEntity(type, level, pos, state,
                saveDataToItem);
        level.method_8652(pos, state.method_26227().method_15759(), 3);
        level.method_8649(entity);
        return entity;
    }

    public void setSaveTileDataToItem(boolean b) {
        this.saveTileDataToItem = b;
    }

    @Override
    public void method_5652(class_2487 tag) {
        super.method_5652(tag);
        tag.method_10556("saveToItem", this.saveTileDataToItem);
    }

    @Override
    public void method_5749(class_2487 tag) {
        super.method_5749(tag);
        this.saveTileDataToItem = tag.method_10577("saveToItem");
    }

    //workaround
    public void setBlockState(class_2680 state) {
        if (state.method_28498(class_2741.field_12508)) {
            state = state.method_11657(class_2741.field_12508, false);
        }
        class_2487 tag = new class_2487();
        tag.method_10566("BlockState", class_2512.method_10686(state));
        tag.method_10569("Time", this.field_7192);
        this.method_5749(tag);
    }

    @Override
    public class_1542 method_5870(class_1935 itemIn, int offset) {
        class_1799 stack = new class_1799(itemIn);
        if (itemIn instanceof class_2248 && this.saveTileDataToItem && this.field_7194 != null) {
            class_2586 be = class_2586.method_11005(class_2338.field_10980, method_6962(), field_7194, method_37908().method_30349());
            if (be != null) stack.method_57365(be.method_57590());
            else Moonlight.LOGGER.warn("Failed to load block entity for falling block. Block Entity data: {}", field_7194);
        }
        return this.method_5699(stack, offset);
    }

    @Override
    public boolean method_5747(float pFallDistance, float pMultiplier, class_1282 pSource) {
        return super.method_5747(pFallDistance, pMultiplier, pSource);
    }

    public void setCancelDrop(boolean cancelDrop) {
        this.field_7189 = cancelDrop;
    }
}
